using Asp.Versioning;
using Luski.Shared.PublicServers.V1.Enums;
using Luski.Shared.PublicServers.V1.ServerToClient.HTTP;
using LuskiServer.Classes;
using LuskiServer.Classes.TableDef;
using Microsoft.AspNetCore.Mvc;

namespace LuskiServer.Controllers.v1;

[ApiVersion(1)]
[ApiController]
public class SocketRoleController : ControllerBase
{
    [HttpGet]
    [Route(LuskiFunctions.Info.Routes.Default.Base)]
    public IActionResult Get([FromQuery(Name = "id")]long id)
    {
        if (!this.CanTokenRequest(out long ID, out long SID, out IActionResult? toc) && toc != null) return toc;
        if (!Tables.Roles.TryReadRow(out RoleRow row, Roles.ID.CreateParameter(id))) return this.ShowError(ErrorCode.Forbidden, "Role does not exist");
        return this.ResponseToResult(new RoleSTC()
        {
            ID = row.ID,
            ServerPermissions = row.ServerPermissions,
            Description = row.Description,
            DisplayName = row.DisplayName,
            Index = row.Index,
            Name = row.Name,
            Members = row.MembersList,
            Color = Convert.ToHexString(row.Color)
        });
    }
    
    [HttpGet]
    [Route(LuskiFunctions.Info.Routes.Default.Base + "/GetAll")]
    public IActionResult GetAll()
    {
        if (!this.CanTokenRequest(out long ID, out long SID, out IActionResult? toc) && toc != null) return toc;
        RoleRow[] rows = Tables.Roles.ReadRows();

        List<RoleSTC> r = new();
        for (int i = 0; i < rows.Length; i++)
        {
            r.Add(new()
            {
                ID = rows[i].ID,
                ServerPermissions = rows[i].ServerPermissions,
                Description = rows[i].Description,
                DisplayName = rows[i].DisplayName,
                Index = rows[i].Index,
                Name = rows[i].Name,
                Members = rows[i].MembersList,
                Color = Convert.ToHexString(rows[i].Color)
            });
        }
        return this.ResponseToResult(new RolesSTC()
        {
            Roles = r.ToArray()
        });
    }
}